@@ -28,7 +28,7 @@ class ComponentData;
 
 class ComponentPage : public ComponentPageUI, public PageWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:  
   ComponentPage( ComponentData *data, Component *component, TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
