@@ -41,7 +41,7 @@ class KioskRun : public TQObject
 {
   friend class KioskGui;
 
-  Q_OBJECT
+  TQ_OBJECT
   
 public:  
   static KioskRun* self() { return s_self; }
@@ -213,7 +213,7 @@ private:
 
 class KioskRunProgressDialog : public KProgressDialog
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
    KioskRunProgressDialog(TQWidget *parent, const char *name, 
