@@ -26,7 +26,7 @@
 
 class PanelComponent: public Component
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:  
   PanelComponent( TQObject *parent = 0);
